pub struct BodyLandmarkFrame {Show 19 fields
pub sacroiliac_joint: Landmark,
pub suprasternal_notch: Landmark,
pub nose: Landmark,
pub left_ear: Landmark,
pub right_ear: Landmark,
pub left_shoulder: Landmark,
pub right_shoulder: Landmark,
pub left_elbow: Landmark,
pub right_elbow: Landmark,
pub left_wrist: Landmark,
pub right_wrist: Landmark,
pub left_hip: Landmark,
pub right_hip: Landmark,
pub left_knee: Landmark,
pub right_knee: Landmark,
pub left_ankle: Landmark,
pub right_ankle: Landmark,
pub left_foot_index: Landmark,
pub right_foot_index: Landmark,
}Expand description
Body-landmark positions for one frame (19 MAIA landmarks).
Fields
sacroiliac_joint: Landmarksuprasternal_notch: Landmarknose: Landmarkleft_ear: Landmarkright_ear: Landmarkleft_shoulder: Landmarkright_shoulder: Landmarkleft_elbow: Landmarkright_elbow: Landmarkleft_wrist: Landmarkright_wrist: Landmarkleft_hip: Landmarkright_hip: Landmarkleft_knee: Landmarkright_knee: Landmarkleft_ankle: Landmarkright_ankle: Landmarkleft_foot_index: Landmarkright_foot_index: LandmarkImplementations
Sourceimpl BodyLandmarkFrame
impl BodyLandmarkFrame
Sourcepub const fn from_array(values: [Landmark; 19]) -> Self
pub const fn from_array(values: [Landmark; 19]) -> Self
Builds a frame from its values in wire order.
Useful for the Zendo server, which produces frames to encode rather than decoding them.
Sourcepub const fn get(&self, key: LandmarkName) -> Landmark
pub const fn get(&self, key: LandmarkName) -> Landmark
Looks up a single value by name.
Sourcepub fn iter(&self) -> impl Iterator<Item = (LandmarkName, Landmark)>
pub fn iter(&self) -> impl Iterator<Item = (LandmarkName, Landmark)>
Iterates over (name, value) pairs in wire order.