HandLandmarkFrame

Struct HandLandmarkFrame 

pub struct HandLandmarkFrame {
Show 21 fields pub wrist: Landmark, pub thumb_cmc: Landmark, pub thumb_mcp: Landmark, pub thumb_ip: Landmark, pub thumb_tip: Landmark, pub index_mcp: Landmark, pub index_pip: Landmark, pub index_dip: Landmark, pub index_tip: Landmark, pub middle_mcp: Landmark, pub middle_pip: Landmark, pub middle_dip: Landmark, pub middle_tip: Landmark, pub ring_mcp: Landmark, pub ring_pip: Landmark, pub ring_dip: Landmark, pub ring_tip: Landmark, pub pinky_mcp: Landmark, pub pinky_pip: Landmark, pub pinky_dip: Landmark, pub pinky_tip: Landmark,
}
Hand-landmark positions for one frame (21 BlazePose hand landmarks).

Fields

wrist: Landmarkthumb_cmc: Landmarkthumb_mcp: Landmarkthumb_ip: Landmarkthumb_tip: Landmarkindex_mcp: Landmarkindex_pip: Landmarkindex_dip: Landmarkindex_tip: Landmarkmiddle_mcp: Landmarkmiddle_pip: Landmarkmiddle_dip: Landmarkmiddle_tip: Landmarkring_mcp: Landmarkring_pip: Landmarkring_dip: Landmarkring_tip: Landmarkpinky_mcp: Landmarkpinky_pip: Landmarkpinky_dip: Landmarkpinky_tip: Landmark

Implementations

Source

impl HandLandmarkFrame

pub const fn from_array(values: [Landmark; 21]) -> Self

Builds a frame from its values in wire order.

Useful for the Zendo server, which produces frames to encode rather than decoding them.

pub const fn to_array(&self) -> [Landmark; 21]

Returns the frame’s values in wire order.

pub const fn get(&self, key: HandLandmarkName) -> Landmark

Looks up a single value by name.

pub fn iter(&self) -> impl Iterator<Item = (HandLandmarkName, Landmark)>

Iterates over (name, value) pairs in wire order.